@@ -312,7 +312,7 @@ def _get_socket_opts(keepalive=True,
 
 class Client(object):
     """
-    Crate connection client using crate's HTTP API.
+    Crate connection client using CrateDB's HTTP API.
     """
 
     SQL_PATH = '/_sql'
@@ -328,7 +328,7 @@ class Client(object):
                  servers=None,
                  timeout=None,
                  backoff_factor=0,
-                 verify_ssl_cert=False,
+                 verify_ssl_cert=True,
                  ca_cert=None,
                  error_trace=False,
                  cert_file=None,
@@ -346,6 +346,22 @@ class Client(object):
             servers = [self.default_server]
         else:
             servers = _to_server_list(servers)
+
+        # Try to derive credentials from first server argument if not
+        # explicitly given.
+        if servers and not username:
+            try:
+                url = urlparse(servers[0])
+                if url.username is not None:
+                    username = url.username
+                if url.password is not None:
+                    password = url.password
+            except Exception as ex:
+                logger.warning("Unable to decode credentials from database "
+                               "URI, so connecting to CrateDB without "
+                               "authentication: {ex}"
+                               .format(ex=ex))
+
         self._active_servers = servers
         self._inactive_servers = []
         pool_kw = _pool_kw_args(
@@ -544,8 +560,8 @@ class Client(object):
                                        (ts, server, message))
                     else:
                         self._active_servers.append(server)
-                        logger.warn("Restored server %s into active pool",
-                                    server)
+                        logger.warning("Restored server %s into active pool",
+                                       server)
 
             # if none is old enough, use oldest
             if not self._active_servers:
@@ -568,6 +584,15 @@ class Client(object):
         """
         Drop server from active list and adds it to the inactive ones.
         """
+
+        # Try to close resource first.
+        try:
+            self.server_pool[server].close()
+        except Exception as ex:
+            logger.warning("When removing server from active pool, "
+                           "resource could not be closed: %s", ex)
+
+        # Apply bookkeeping.
         try:
             self._active_servers.remove(server)
         except ValueError:
@@ -576,7 +601,7 @@ class Client(object):
             heapq.heappush(self._inactive_servers, (time(), server, message))
             logger.warning("Removed server %s from active pool", server)
 
-        # if this is the last server raise exception, otherwise try next
+        # If this is the last server, raise an exception.
         if not self._active_servers:
             raise ConnectionError(
                 ("No more Servers available, "
